@@ -29,17 +29,17 @@ SEXP R_ssh_write_file_writer(SEXP ptr, SEXP buf, SEXP close){
   } else if(Rf_length(buf)) {
     fflush(fp);
   }
-  return ScalarInteger(len);
+  return Rf_ScalarInteger(len);
 }
 
 SEXP R_ssh_new_file_writer(SEXP path){
   SEXP ptr = PROTECT(R_MakeExternalPtr(NULL, path, R_NilValue));
   R_RegisterCFinalizerEx(ptr, fin_file_writer, TRUE);
-  setAttrib(ptr, R_ClassSymbol, mkString("file_writer"));
+  Rf_setAttrib(ptr, R_ClassSymbol, Rf_mkString("file_writer"));
   UNPROTECT(1);
   return ptr;
 }
 
 SEXP R_ssh_total_writers(void){
-  return(ScalarInteger(total_open_writers));
+  return(Rf_ScalarInteger(total_open_writers));
 }
